#include <stdint.h>

//*****************************************************************************
//
// Enable the IAR extensions for this source file.
//
//*****************************************************************************
#pragma language=extended

//*****************************************************************************
//
// Forward declaration of the default fault handlers.
//
//*****************************************************************************
void resetISR(void);
static void nmiSR(void);
static void faultISR(void);
static void defaultISR(void);

//*****************************************************************************
//
// External declaration for the interrupt handler used by the application.
//
//*****************************************************************************
extern void SysTickIntHandler(void);

extern void Port1IsrHandler(void);

extern void TimerA1_ISR(void);

extern void IntSpiGPIOHandler(void);

extern void EUSCIA0_UART_ISR(void);


//*****************************************************************************
//
// The entry point for the application startup code.
//
//*****************************************************************************
extern void __iar_program_start(void);

//*****************************************************************************
//
// Reserve space for the system stack.
//
//*****************************************************************************
static uint32_t systemStack[128] @ ".noinit";

//*****************************************************************************
//
// A union that describes the entries of the vector table.  The union is needed
// since the first entry is the stack pointer and the remainder are function
// pointers.
//
//*****************************************************************************
typedef union
{
    void (*handler)(void);
    uint32_t ptr;
}
uVectorEntry;

//*****************************************************************************
//
// The vector table.  Note that the proper constructs must be placed on this to
// ensure that it ends up at physical address 0x0000.0000.
//
//*****************************************************************************
__root const uVectorEntry __vector_table[] @ ".intvec" =
{
    { .ptr = (uint32_t)systemStack + sizeof(systemStack) },
                                            // The initial stack pointer
    resetISR,                               // The reset handler
    nmiSR,                                  // The NMI handler
    faultISR,                               // The hard fault handler

    defaultISR,                             // The MPU fault handler

    defaultISR,                             // The bus fault handler

    defaultISR,                             // The usage fault handler

    0,                                      // Reserved

    0,                                      // Reserved

    0,                                      // Reserved

    0,                                      // Reserved

    defaultISR,                             // SVCall handler

    defaultISR,                             // Debug monitor handler

    0,                                      // Reserved

    defaultISR,                             // The PendSV handler

    SysTickIntHandler,                      // The SysTick handler

    defaultISR,                             // PSS ISR

    defaultISR,                             // CS ISR

    defaultISR,                             // PCM ISR

    defaultISR,                             // WDT ISR

    defaultISR,                             // FPU ISR

    defaultISR,                             // FLCTL ISR

    defaultISR,                             // COMP0 ISR

    defaultISR,                             // COMP1 ISR

    defaultISR,                             // TA0_0 ISR

    defaultISR,                             // TA0_N ISR

    TimerA1_ISR,                            // TA1_0 ISR

    defaultISR,                             // TA1_N ISR

    defaultISR,                             // TA2_0 ISR

    defaultISR,                             // TA2_N ISR

    defaultISR,                             // TA3_0 ISR

    defaultISR,                             // TA3_N ISR

    EUSCIA0_UART_ISR,                       // EUSCIA0 ISR

    defaultISR,                             // EUSCIA1 ISR

    defaultISR,                             // EUSCIA2 ISR

    defaultISR,                             // EUSCIA3 ISR

    defaultISR,                             // EUSCIB0 ISR

    defaultISR,                             // EUSCIB1 ISR

    defaultISR,                             // EUSCIB2 ISR

    defaultISR,                             // EUSCIB3 ISR

    defaultISR,                             // ADC14 ISR

    defaultISR,                             // T32_INT1 ISR

    defaultISR,                             // T32_INT2 ISR

    defaultISR,                             // T32_INTC ISR

    defaultISR,                             // AES ISR

    defaultISR,                             // RTC ISR

    defaultISR,                             // DMA_ERR ISR

    defaultISR,                             // DMA_INT3 ISR

    defaultISR,                             // DMA_INT2 ISR

    defaultISR,                             // DMA_INT1 ISR

    defaultISR,                             // DMA_INT0 ISR

    Port1IsrHandler,                        // PORT1 ISR

    IntSpiGPIOHandler,                      // PORT2 ISR

    defaultISR,                             // PORT3 ISR

    defaultISR,                             // PORT4 ISR

    defaultISR,                             // PORT5 ISR

    defaultISR,                             // PORT6 ISR

    defaultISR,                             // Reserved 41

    defaultISR,                             // Reserved 42

    defaultISR,                             // Reserved 43

    defaultISR,                             // Reserved 44

    defaultISR,                             // Reserved 45

    defaultISR,                             // Reserved 46

    defaultISR,                             // Reserved 47

    defaultISR,                             // Reserved 48

    defaultISR,                             // Reserved 49

    defaultISR,                             // Reserved 50

    defaultISR,                             // Reserved 51

    defaultISR,                             // Reserved 52

    defaultISR,                             // Reserved 53

    defaultISR,                             // Reserved 54

    defaultISR,                             // Reserved 55

    defaultISR,                             // Reserved 56

    defaultISR,                             // Reserved 57

    defaultISR,                             // Reserved 58

    defaultISR,                             // Reserved 59

    defaultISR,                             // Reserved 60

    defaultISR,                             // Reserved 61

    defaultISR,                             // Reserved 62

    defaultISR,                             // Reserved 63

    defaultISR                              // Reserved 64

};

//*****************************************************************************
//
// This is the code that gets called when the processor first starts execution
// following a reset event.  Only the absolutely necessary set is performed,
// after which the application supplied entry() routine is called.  Any fancy
// actions (such as making decisions based on the reset cause register, and
// resetting the bits in that register) are left solely in the hands of the
// application.
//
//*****************************************************************************
void
resetISR(void)
{


    //
    // Call the application's entry point.
    //
    __iar_program_start();
}

//*****************************************************************************
//
// This is the code that gets called when the processor receives a NMI.  This
// simply enters an infinite loop, preserving the system state for examination
// by a debugger.
//
//*****************************************************************************
static void
nmiSR(void)
{
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}

//*****************************************************************************
//
// This is the code that gets called when the processor receives a fault
// interrupt.  This simply enters an infinite loop, preserving the system state
// for examination by a debugger.
//
//*****************************************************************************
static void
faultISR(void)
{
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}

//*****************************************************************************
//
// This is the code that gets called when the processor receives an unexpected
// interrupt.  This simply enters an infinite loop, preserving the system state
// for examination by a debugger.
//
//*****************************************************************************
static void
defaultISR(void)
{
    //
    // Go into an infinite loop.
    //
    while(1)
    {
    }
}
