/**
 * Created by a0389339 on 6/13/2014.
 */

var CCS_TOOLS_VERSION = ".2";

var request = require('request');
var https = require( 'https' );
var ws = require( 'ws' );
var qs = require('querystring');
var fs = require("fs");
var path = require("path");
var logger = require('./logger.js');

// MSG_TYPES
var MSG_TYPES = {
    WAITING_FOR_BINARY_DATA : "DS_WAITING_FOR_BINARY_DATA",
    ERROR : "DS_ERROR",
    SUCCESS : "DS_SUCCESS",
    OUTPUT_TEXT : "DS_OUTPUT_TEXT",
    OUTPUT_SERIAL_TEXT : "DS_SERIAL_TEXT"
};

// supported commands
var serial = require( './serial.js' );
var debugCommands = { "debug.loadProgram" : require('./load_program.js') ,
                      "serial.list" : serial.list,
                      "serial.open" : serial.open,
                      "serial.close" : serial.close };

var certOptions = {
    key: fs.readFileSync( path.join( __dirname, "cert", "server.key")),
    cert: fs.readFileSync( path.join( __dirname, "cert", "server.crt"))
};

// create a https server
// listener - callback function after the server has been created
// port - default port to try on which to create the server
var createServer = function( listener, port ) {

    var numTries = 0;

    // use create server to find an available port
    var server = https.createServer( certOptions,  function (req, res) {


        response.writeHead(200);
        response.end();


    });

    var internalListener = function () {
        listener( server );
    };

    server.on ( 'error', function() {

        numTries++;

        // potential error on attempting to listen, mostly due to default port being already used; in which case we let the
        // server find the available port, try maximum of 3 ties to avoid some sort of an error loop
        if( numTries <= 3 ) {
            server.listen();
        }

    });

    // try user specified port
    if( port ) {
        server.listen( port, internalListener );
    } else {
        server.listen( internalListener );
    }


};

var registerWithRemoteServer = function(  server , programArgs ) {

    var regParams = {
        sessionID : programArgs.sessionID,
        port : server.address().port,
        version : CCS_TOOLS_VERSION
    };

    var regPath = programArgs.registrationAPI + "?" + qs.stringify( regParams );
    var proxyfinder = require( './find_proxy.js');
    proxyfinder.get( function( proxy ) {

        // append http if needed
        if( proxy !== "" && proxy.indexOf("http") < 0 ) {
            proxy = "http://" + proxy;
        }

        logger.info( "Using proxy : " + proxy);
        request({'url': regPath, rejectUnauthorized: false,
            'proxy': proxy}, function (error, response, body) {
            if (!error && response.statusCode == 200) {
                logger.info("Registration with remote server successful");
                logger.info(body);
            } else {
                logger.info("Registration with remote server failed! : " + error);
            }
        });
    }, regPath );

};

var wsMsgLogger = {

      connectionExists : function( context, exit )  {
          var msg =  context + " : An active web socket connection already exists.";
              msg += exit ?  "Exiting Application!" : "";
          logger.info( msg );
      },

      waitingForConnection : function( context ) {
          logger.info( context + ": Waiting for connection" );
      },

    connectionEstablished : function( context ) {
        logger.info( context + " : Web Socket Connection Established" );
    },

    closeWSS : function( context ) {
        logger.info( context + " : Closed Web Socket Server" );
    },

    closeWS : function( context ) {
        logger.info( context + " : Closed Web Socket" );
    }

};

var startWebSocketServer = function ( server ) {

    var WebSocketServer = ws.Server;
    var wssMain = new WebSocketServer( { server : server } );

    wssMain.on('connection', function( wsMain ) {

        if( wsMain.upgradeReq.connection.remoteAddress !== "127.0.0.1" ) {
            logger.info( "Received request from non localhost -> " + wsMain.upgradeReq.connection.remoteAddress);
            return;
        }

        if( wssMain.clients.length > 1 ) {
            wsMsgLogger.connectionExists( "Main" , true );
            process.exit();
        }

        wsMain.on('message', function( jsonData ) {

            var data = JSON.parse( jsonData );

            // create a socket server and hook up the command
            createServer( function( server ) {

                var command = debugCommands[data.command];
                var wssCommand = new WebSocketServer( { server : server } );

                // notify main with port we are listening on
                wsMain.send( JSON.stringify( { port : server.address().port } ) );

                wssCommand.on('connection', function( wsCommand ) {

                    if ( wssCommand.clients.length > 1 ) {
                        wsMsgLogger.connectionExists( data.command );
                        return;
                    }

                    // object for sending output
                    var output = {
                        text : function( data ) {
                            var obj = {
                                msgType : MSG_TYPES.OUTPUT_TEXT,
                                data : data
                            };
                            wsCommand.send( JSON.stringify( obj ) );
                        },
                        error : function( data ) {
                            var obj = {
                                msgType : MSG_TYPES.ERROR,
                                data : data
                            };
                            wsCommand.send( JSON.stringify( obj ) );
                        },
                        waitingForBinaryData : function() {
                            var obj = {
                                msgType: MSG_TYPES.WAITING_FOR_BINARY_DATA,
                                data: ""
                            };
                            wsCommand.send( JSON.stringify( obj ) );
                        },
                        success : function( data ) {
                            var obj = {
                                msgType: MSG_TYPES.SUCCESS,
                                data: data
                            };
                            wsCommand.send( JSON.stringify( obj ) );
                        },
                        serialText : function( data ) {
                            var obj = {
                                msgType: MSG_TYPES.OUTPUT_SERIAL_TEXT,
                                data: data
                            };
                            wsCommand.send( JSON.stringify( obj ) );
                        },
                        close : function() {
                            wsCommand.close();
                            wssCommand.close();
                        }
                    };

                    var input = debugCommands[data.command]( output, data );
                    wsCommand.on( 'message', function( message , flags ) {
                        var data = flags.binary ? message : JSON.parse( message );
                        input.data( data );
                    } );

                    wsCommand.on( 'close', function() {
                        if( input.close )
                            input.close();
                        wsMsgLogger.closeWS( data.command );
                    });

                    wsMsgLogger.connectionEstablished( data.command );

                } );

                wssCommand.on('close', function() {
                    wsMsgLogger.closeWSS( data.command );
                });

                wsMsgLogger.waitingForConnection( data.command );

            });

        });

        wsMain.on('close', function() {
           wsMsgLogger.closeWS( "Main" );
           process.exit();
        });

        wsMsgLogger.connectionEstablished("Main");
    });

    // Exit application if a websocket connection has not been established within a 30 secs
    setTimeout( function() {
        if( wssMain.clients.length === 0 ) {
            logger.info("Web socket connection not established within 30 secs. Exiting Application");
            process.exit();
        }
 //   }, 30000 );
 //30 second timeout extended to 10 minutes to enable debugging 
    }, 600000 );
 

    wssMain.on( "close" , function() {
        wsMsgLogger.closeWSS("Main");
    })


    logger.info( "Web Socket Server Started ( Main ) -> localhost:" + server.address().port );
    wsMsgLogger.waitingForConnection( "Main" );
};



// main handler exposed to ccstools to handle debug functionality
module.exports = function ( programArgs ) {

    createServer( function ( server ) {
        startWebSocketServer( server );
        registerWithRemoteServer( server, programArgs );
    }, programArgs.wsPort );

};