// Set this to override proxy look up
var proxy = "";

var util = require( './util.js' );
var logger = require('./logger.js');
var execFile = require('child_process').execFile;
var exec = require('child_process').exec;
var request = require('request');
var os = require('os');
var fs = require('fs');

logger.info( "Overridden Proxy = " + proxy );

 // determine the proxy utility path relative to the loaders directory
    // avoid having multiple env variabls
var loadersDirPath = process.env.LOADERS_DIR_PATH ? process.env.LOADERS_DIR_PATH : '../loaders';

// default def
var findProxy = function ( callback, url ) {
  return callback( proxy );
};

if( util.isWin ) {
   
    var proxyExe = loadersDirPath + "/../util/proxyfinder.exe";
    
    findProxy = function( callback , url ) {
        logger.info( "Looking up proxy settings for url " + url );
        execFile( proxyExe, [url], {}, function (err, data) {
            if( err ) {
                logger.info( "Proxy look up failed : " + url );
                logger.info( err );
            } else {
                logger.info( "Setting proxy to " + data);
                proxy = data;
            }
            callback( proxy );
        });
    };

} else if( util.isOSX ) {

      var makeScutilReader = function( text ) {
 
      var KeyProxyAutoConfigEnable = "ProxyAutoConfigEnable";
      var KeyProxyAutoConfigURLString = "ProxyAutoConfigURLString";
      var KeyHTTPEnable = "HTTPEnable";
      var KeyHTTPProxy = "HTTPProxy";
      var KeyHTTPPort = "HTTPPort";
     
      var isEnabled = function ( option ) {
        var option = text.match( new RegExp( "^.*" + option + ".*:.*1.*$", "m" )); // match line
        return option ? true : false;
      };

      var getValue = function ( option ) {
        var option = text.match( new RegExp( "^.*" + option + ".*$", "m" ) ); // match the line with value
        if( option ) {
          return option[0].split(" : ")[1].trim(); // extract the http value
        }
        else {
          return "";
        }
      };

      return {
        isAutoConfigEnable : function () {
          return isEnabled( KeyProxyAutoConfigEnable );
        },
        autoConfigURLString : function() {
          return getValue( KeyProxyAutoConfigURLString );
        },
        isHttpEnabled : function() {
          return isEnabled( KeyHTTPEnable );
        },
        httpProxy : function() {
          return getValue( KeyHTTPProxy );
        },
        httpPort : function() {
          return getValue( KeyHTTPPort );
        }
      };

    };

    var findProxy = function( callback , url) {

     exec ( "scutil --proxy",  function( err, out ) {
        
        var text = out;
        var scutilReader = makeScutilReader( text );
        
        if( scutilReader.isAutoConfigEnable() ) {
          
          var pacFileUrl = scutilReader.autoConfigURLString();
          var tempPacFile = os.tmpdir() + "proxy.pac";

          request( pacFileUrl ).pipe( fs.createWriteStream( tempPacFile ) ).on( 'finish',
              function() {
                 
                 var pacTesterExe = loadersDirPath + "/../util/pactester";
                 // parse the pac file
                  execFile( pacTesterExe, ["-p",tempPacFile,"-u",url],function( err, out , stderr ) {
                    if( !err && out !== "") {
                      var out = out.trim();
                      if( out !== "DIRECT" ){
                        proxy = out.replace("PROXY","").trim();
                      }
                    } else {
                      logger.info( "err : " +  err );
                      logger.info( "stderr : " + stderr );
                    }
                    callback( proxy );
                  });
              }
            );

        } else {
          logger.info( "auto config script disabled" );
           if ( scutilReader.isHttpEnabled() ) {
            proxy = scutilReader.httpProxy() + ":" + scutilReader.httpPort();
           }
          callback( proxy );
        }

    });
  }

} else {
    findProxy = function( callback, url ) {
        if (process.env.http_proxy) {
            proxy = process.env.http_proxy;
        }
        callback(proxy);
    };
}

exports.get = function ( callback, url ) {

    // clean up url by removing the query string
    url = url.split('?')[0];

    if( proxy !== "" ) {
        callback(proxy);
    } else {
        findProxy( callback, url );
    };

};